@@ -1,23 +1,22 @@
 from django_filters import rest_framework as filters
-from munity.views import MunityGroupableMixin, MunityViewSet
+from munity.views import MunityWorkspaceViewSet
 from rest_framework import serializers
 
+from ..models import MunityGroupableModel
 from .models import GenericGroup
 
-
 class GenericGroupSerializer(serializers.ModelSerializer):
     class Meta:
         fields = [
             "id",
             "label",
             "generic_groups",
+            "workspace",
             "created",
             "modified",
         ]
-        depth = 1
         model = GenericGroup
 
-
 class GenericGroupsFilter(filters.FilterSet):
     class Meta:
         fields = {
@@ -30,17 +29,6 @@ class GenericGroupsFilter(filters.FilterSet):
         model = GenericGroup
 
 
-class GenericGroupsViewSet(MunityViewSet, MunityGroupableMixin):
+class GenericGroupsViewSet(MunityWorkspaceViewSet):
     serializer_class = GenericGroupSerializer
     filterset_class = GenericGroupsFilter
-
-    def perform_create(self, serializer):
-        MunityGroupableMixin.perform_create(self, serializer)
-        MunityViewSet.perform_create(self, serializer)
-    def perform_update(self, serializer):
-        MunityGroupableMixin.perform_update(self, serializer)
-        MunityViewSet.perform_update(self, serializer)
-    def perform_destroy(self, instance):
-        MunityGroupableMixin.perform_destroy(self, instance)
-        MunityViewSet.perform_destroy(self, instance)
-
