@@ -14,12 +14,11 @@ overmind_router.register(r"roles", RolesViewSet, basename="role")
 overmind_router.register(r"generic_groups", GenericGroupsViewSet, basename="group")
 overmind_router.register(r"permissions", PermissionsViewSet, basename="permission")
 overmind_router.register(r"settings", SettingsViewSet, basename="permission")
-overmind_router.register(r"", PermissionsViewSet, basename="permission")
 
 workspace_router = nested_routers.NestedSimpleRouter(overmind_router, r'workspaces', lookup='workspace')
 workspace_router.register(r"users", UsersViewSet, basename="workspace-user")
-workspace_router.register(r"roles", UsersViewSet, basename="workspace-user")
-workspace_router.register(r"generic_groups", UsersViewSet, basename="workspace-user")
-workspace_router.register(r"permissions", UsersViewSet, basename="workspace-user")
+workspace_router.register(r"roles", RolesViewSet, basename="workspace-user")
+workspace_router.register(r"generic_groups", GenericGroupsViewSet, basename="workspace-user")
+workspace_router.register(r"permissions", PermissionsViewSet, basename="workspace-user")
 workspace_router.register(r"settings", SettingsViewSet, basename="permission")
 
